==> pyTermTk-0.30.0a31.tar.gz: pyTermTk-0.30.0a31/TermTk/TTkUiTools/properties/splitter.py <==
#!/usr/bin/env python3

# MIT License
#
# Copyright (c) 2023 Eugenio Parodi <ceccopierangiolieugenio AT googlemail DOT com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from TermTk.TTkCore.constant import TTkK
from TermTk.TTkWidgets.splitter import TTkSplitter

TTkSplitterProperties = {
    'properties' : {
        'Border' : {
                'init': {'name':'border', 'type':bool } },
        'Orientation' : {
                'init': {'name':'orientation', 'type':'singleflag',
                    'flags': {
                        'Horizontal' : TTkK.HORIZONTAL ,
                        'Vertical'   : TTkK.VERTICAL   } } ,
                'get':  {'cb':TTkSplitter.orientation,     'type':'singleflag',
                    'flags': {
                        'Horizontal' : TTkK.HORIZONTAL ,
                        'Vertical'   : TTkK.VERTICAL   } } }
    },'signals' : {},'slots' : {}
}

==> pyTermTk-0.31.0a1.tar.gz: pyTermTk-0.31.0a1/TermTk/TTkUiTools/properties/splitter.py <==
#!/usr/bin/env python3

# MIT License
#
# Copyright (c) 2023 Eugenio Parodi <ceccopierangiolieugenio AT googlemail DOT com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from TermTk.TTkCore.constant import TTkK
from TermTk.TTkWidgets.splitter import TTkSplitter

TTkSplitterProperties = {
    'properties' : {
        'Border' : {
                'init': {'name':'border', 'type':bool },
                'get':  {'cb':TTkSplitter.border,     'type':bool } ,
                'set':  {'cb':TTkSplitter.setBorder,  'type':bool } },
        'Orientation' : {
                'init': {'name':'orientation', 'type':'singleflag',
                    'flags': {
                        'Horizontal' : TTkK.HORIZONTAL ,
                        'Vertical'   : TTkK.VERTICAL   } } ,
                'get':  {'cb':TTkSplitter.orientation,     'type':'singleflag',
                    'flags': {
                        'Horizontal' : TTkK.HORIZONTAL ,
                        'Vertical'   : TTkK.VERTICAL   } } ,
                'set':  {'cb':TTkSplitter.setOrientation,  'type':'singleflag',
                    'flags': {
                        'Horizontal' : TTkK.HORIZONTAL ,
                        'Vertical'   : TTkK.VERTICAL   } } }
    },'signals' : {},'slots' : {}
}
